""" Main entry point for the command line executable `wheatley`. """

if __name__ == "__main__":
    from wheatley.main import main

    main()
